==> weavel-0.3.0-py3-none-any.whl: weavel/_buffer_storage.py <==
from __future__ import annotations

from threading import Condition, Lock
from typing import Dict, List, Union

from weavel.types import (
    OpenTraceBody,
    CaptureActionEventBody,
    CaptureTraceDataBody,
)


class BufferStorage:
    def __init__(self, max_buffer_size: int):
        self.max_buffer_size = max_buffer_size
        self.buffer: List[Union[OpenTraceBody, CaptureActionEventBody, CaptureTraceDataBody]] = []
        self.buffer_lock = Lock()
        self.not_full_cv = Condition(self.buffer_lock)
        self.not_empty_cv = Condition(self.buffer_lock)

    @property
    def buffer_size(self) -> int:
        return len(self.buffer)

    def push(self, event: Dict) -> None:
        with self.buffer_lock:
            while self.buffer_size >= self.max_buffer_size:
                self.not_empty_cv.notify()  # immediately wake up possibly sleeping consumer
                self.not_full_cv.wait()
            self.buffer.append(event)
            if self.buffer_size >= self.max_buffer_size:
                self.not_empty_cv.notify()

    def pull(self, batch_size: int) -> List[Union[OpenTraceBody, CaptureActionEventBody, CaptureTraceDataBody]]:
        while not self.buffer_size:
            self.not_empty_cv.wait()
        pull_size = min(batch_size, self.buffer_size)
        out = self.buffer[:pull_size]
        self.buffer = self.buffer[pull_size:]
        self.not_full_cv.notify()
        return out

    def pull_all(self) -> List[Union[OpenTraceBody, CaptureActionEventBody, CaptureTraceDataBody]]:
        out = self.buffer[:]
        self.buffer = []
        self.not_full_cv.notify()
        return out

==> weavel-0.4.1-py3-none-any.whl: weavel/_buffer_storage.py <==
from __future__ import annotations

from threading import Condition, Lock
from typing import Dict, List, Union

from weavel.types import (
    OpenTraceBody,
    CaptureTrackEventBody,
    CaptureTraceDataBody,
)


class BufferStorage:
    def __init__(self, max_buffer_size: int):
        self.max_buffer_size = max_buffer_size
        self.buffer: List[
            Union[OpenTraceBody, CaptureTrackEventBody, CaptureTraceDataBody]
        ] = []
        self.buffer_lock = Lock()
        self.not_full_cv = Condition(self.buffer_lock)
        self.not_empty_cv = Condition(self.buffer_lock)

    @property
    def buffer_size(self) -> int:
        return len(self.buffer)

    def push(self, event: Dict) -> None:
        with self.buffer_lock:
            while self.buffer_size >= self.max_buffer_size:
                self.not_empty_cv.notify()  # immediately wake up possibly sleeping consumer
                self.not_full_cv.wait()
            self.buffer.append(event)
            if self.buffer_size >= self.max_buffer_size:
                self.not_empty_cv.notify()

    def pull(
        self, batch_size: int
    ) -> List[Union[OpenTraceBody, CaptureTrackEventBody, CaptureTraceDataBody]]:
        while not self.buffer_size:
            self.not_empty_cv.wait()
        pull_size = min(batch_size, self.buffer_size)
        out = self.buffer[:pull_size]
        self.buffer = self.buffer[pull_size:]
        self.not_full_cv.notify()
        return out

    def pull_all(
        self,
    ) -> List[Union[OpenTraceBody, CaptureTrackEventBody, CaptureTraceDataBody]]:
        out = self.buffer[:]
        self.buffer = []
        self.not_full_cv.notify()
        return out
